/**
 * 用户分析器
 * 提供深度的用户行为分析、兴趣挖掘和影响力评估
 */
export declare class UserAnalyzer {
    /**
     * 深度用户行为分析
     */
    analyzeUserBehavior(userId: string): Promise<{
        user_id: string;
        basic_info: {
            user_name: string;
            level: number;
            join_days: number;
        };
        creation_pattern: {
            content_frequency: {
                frequency_level: string;
                total_per_month: number;
            };
            content_quality: {
                avg_article_engagement: number;
                avg_pin_engagement: number;
            };
            topic_diversity: {
                unique_topics: number;
                diversity_score: number;
            };
            engagement_effectiveness: {
                engagement_rate: number;
            };
            creation_consistency: {
                consistency_score: number;
            };
            preferred_formats: {
                preferred_format: string;
            };
        };
        interaction_pattern: {
            interaction_ratio: number;
            social_activity: {
                following_ratio: number;
                influence_ratio: number;
                social_balance: number;
            };
            engagement_style: "balanced" | "creator_focused" | "community_focused";
            community_involvement: "low" | "medium" | "high";
        };
        influence_network: {
            network_size: number;
            influence_score: number;
            network_quality: string;
            growth_potential: string;
        };
        growth_trajectory: {
            estimated_join_days: number;
            daily_content_rate: number;
            daily_engagement_rate: number;
            growth_stage: "newcomer" | "growing" | "established" | "veteran";
            growth_momentum: "low" | "medium" | "high";
        };
        behavior_score: number;
        user_type: string;
        analysis_time: string;
    }>;
    /**
     * 分析用户内容创作模式
     */
    private analyzeCreationPattern;
    /**
     * 获取用户文章（模拟，实际需要专门的API）
     */
    private getUserArticles;
    /**
     * 获取用户沸点（模拟，实际需要专门的API）
     */
    private getUserPins;
    /**
     * 分析内容发布频率
     */
    private analyzeContentFrequency;
    /**
     * 分析内容质量
     */
    private analyzeContentQuality;
    /**
     * 分析话题多样性
     */
    private analyzeTopicDiversity;
    /**
     * 分析参与效果
     */
    private analyzeEngagementEffectiveness;
    /**
     * 分析创作一致性
     */
    private analyzeCreationConsistency;
    /**
     * 分析偏好格式
     */
    private analyzePreferredFormats;
    /**
     * 分析用户互动模式
     */
    private analyzeInteractionPattern;
    /**
     * 分析影响力网络
     */
    private analyzeInfluenceNetwork;
    /**
     * 分析成长轨迹
     */
    private analyzeGrowthTrajectory;
    /**
     * 计算行为评分
     */
    private calculateBehaviorScore;
    /**
     * 分类用户类型
     */
    private classifyUserType;
    private getDefaultCreationPattern;
    private classifyDiversityLevel;
    private classifyEffectivenessLevel;
    private classifyConsistencyLevel;
    private calculateSocialBalance;
    private classifyEngagementStyle;
    private assessCommunityInvolvement;
    private calculateInfluenceScore;
    private assessNetworkQuality;
    private assessNetworkGrowthPotential;
    private estimateJoinDays;
    private classifyGrowthStage;
    private calculateGrowthMomentum;
    /**
     * 批量用户行为分析
     */
    batchAnalyzeUsers(userIds: string[]): Promise<({
        user_id: string;
        basic_info: {
            user_name: string;
            level: number;
            join_days: number;
        };
        creation_pattern: {
            content_frequency: {
                frequency_level: string;
                total_per_month: number;
            };
            content_quality: {
                avg_article_engagement: number;
                avg_pin_engagement: number;
            };
            topic_diversity: {
                unique_topics: number;
                diversity_score: number;
            };
            engagement_effectiveness: {
                engagement_rate: number;
            };
            creation_consistency: {
                consistency_score: number;
            };
            preferred_formats: {
                preferred_format: string;
            };
        };
        interaction_pattern: {
            interaction_ratio: number;
            social_activity: {
                following_ratio: number;
                influence_ratio: number;
                social_balance: number;
            };
            engagement_style: "balanced" | "creator_focused" | "community_focused";
            community_involvement: "low" | "medium" | "high";
        };
        influence_network: {
            network_size: number;
            influence_score: number;
            network_quality: string;
            growth_potential: string;
        };
        growth_trajectory: {
            estimated_join_days: number;
            daily_content_rate: number;
            daily_engagement_rate: number;
            growth_stage: "newcomer" | "growing" | "established" | "veteran";
            growth_momentum: "low" | "medium" | "high";
        };
        behavior_score: number;
        user_type: string;
        analysis_time: string;
    } | {
        user_id: string;
        error: string;
    })[]>;
    /**
     * 用户相似度分析
     */
    analyzeUserSimilarity(userId1: string, userId2: string): Promise<{
        user1_id: string;
        user2_id: string;
        overall_similarity: number;
        detailed_similarity: {
            creation_similarity: number;
            interaction_similarity: number;
            topic_similarity: number;
        };
        similarity_level: "low" | "medium" | "high";
    }>;
    private calculateCreationSimilarity;
    private calculateInteractionSimilarity;
    private calculateTopicSimilarity;
    private classifySimilarityLevel;
    /**
     * 计算标准差
     */
    private calculateStandardDeviation;
}
export declare const userAnalyzer: UserAnalyzer;
