import type { PinInfo, Topic } from '../types/index.js';
import _ from 'lodash';
/**
 * 沸点业务逻辑服务
 * 提供沸点数据的高级处理和分析功能
 */
export declare class PinService {
    /**
     * 获取增强的沸点列表
     */
    getEnhancedPinList(params?: {
        sort_type?: number;
        topic_id?: string;
        limit?: number;
        include_sentiment?: boolean;
        include_trend_info?: boolean;
    }): Promise<{
        pins: any[];
        cursor: string | undefined;
        has_more: boolean;
        count: number;
    }>;
    /**
     * 分析沸点情感倾向
     */
    analyzeSentiment(pinInfo: PinInfo): {
        sentiment: "positive" | "negative" | "neutral" | "question";
        confidence: number;
        scores: {
            positive: number;
            negative: number;
            question: number;
        };
    };
    /**
     * 计算沸点趋势
     */
    calculatePinTrend(pinInfo: PinInfo): {
        status: "rising" | "stable" | "declining" | "viral" | "new";
        engagement_rate: number;
        hours_since_publish: number;
        viral_potential: number;
    };
    /**
     * 计算互动速率
     */
    private calculateEngagementRate;
    /**
     * 计算病毒传播潜力
     */
    private calculateViralPotential;
    /**
     * 分析沸点内容
     */
    analyzeContent(pinInfo: PinInfo): {
        length: number;
        has_images: boolean;
        image_count: number;
        has_topic: boolean;
        has_mention: boolean;
        has_link: boolean;
        content_type: string;
        readability_score: number;
    };
    /**
     * 分类内容类型
     */
    private classifyContentType;
    /**
     * 计算可读性评分
     */
    private calculateReadabilityScore;
    /**
     * 计算互动质量评分
     */
    calculateEngagementQuality(pinInfo: PinInfo): number;
    /**
     * 获取热门话题分析
     */
    getTopicAnalysis(timeRange?: number): Promise<{
        time_range_hours: number;
        total_topics: number;
        total_pins: number;
        trending_topics: {
            heat_score: number;
            topic: Topic;
            pin_count: number;
            total_engagement: number;
            avg_engagement: number;
            growth_rate: number;
        }[];
        analysis_time: string;
    }>;
    /**
     * 获取沸点推荐
     */
    getPinRecommendations(params?: {
        user_interests?: string[];
        exclude_ids?: string[];
        limit?: number;
        content_types?: string[];
    }): Promise<{
        pin_id: string;
        content: string;
        reason: string;
        confidence: number;
        content_type: string;
        author: string;
    }[]>;
    /**
     * 计算沸点兴趣匹配分数
     */
    private calculatePinInterestScore;
    /**
     * 生成沸点推荐理由
     */
    private generatePinRecommendationReason;
    /**
     * 获取沸点统计报告
     */
    getPinStatsReport(timeRange?: number): Promise<{
        time_range_hours: number;
        summary: {
            total_pins: number;
            total_diggs: number;
            total_comments: number;
            avg_diggs_per_pin: number;
            avg_comments_per_pin: number;
        };
        content_type_distribution: _.Dictionary<number>;
        hourly_activity: {
            hour: number;
            pin_count: number;
            avg_engagement: number;
        }[];
        top_authors: {
            user_name: string;
            pin_count: number;
            total_engagement: number;
        }[];
        engagement_trends: {
            hour: string;
            total_engagement: number;
            pin_count: number;
            avg_engagement: number;
        }[];
    }>;
    /**
     * 获取最活跃作者
     */
    private getTopAuthors;
    /**
     * 计算互动趋势
     */
    private calculateEngagementTrends;
}
export declare const pinService: PinService;
