/**
 * 智能缓存管理器
 * 提供多级缓存和智能过期策略
 */
interface CacheStats {
    hits: number;
    misses: number;
    size: number;
    hitRate: number;
}
export declare class SmartCache<T> {
    private cache;
    private stats;
    private maxSize;
    private defaultTTL;
    constructor(maxSize?: number, defaultTTL?: number);
    /**
     * 设置缓存
     */
    set(key: string, data: T, ttl?: number): void;
    /**
     * 获取缓存
     */
    get(key: string): T | null;
    /**
     * 获取或设置缓存（常用模式）
     */
    getOrSet<R>(key: string, factory: () => Promise<R>, ttl?: number): Promise<R>;
    /**
     * 删除缓存
     */
    delete(key: string): boolean;
    /**
     * 清空缓存
     */
    clear(): void;
    /**
     * 获取缓存统计
     */
    getStats(): CacheStats;
    /**
     * 清理过期缓存
     */
    private cleanup;
    /**
     * LRU淘汰策略
     */
    private evictLRU;
    /**
     * 预热缓存
     */
    warmup(keys: string[], factory: (key: string) => Promise<T>): Promise<void>;
}
/**
 * 缓存键生成器
 */
export declare class CacheKeyGenerator {
    static article(params: any): string;
    static pin(params: any): string;
    static search(type: string, keyword: string, limit: number): string;
    static trend(timeRange: number, category?: string): string;
    static userAnalysis(userId: string): string;
    static recommendation(userId: string, interests: string[], algorithm: string): string;
    static quality(contentId: string, contentType: string): string;
}
/**
 * 分层缓存管理器
 */
export declare class LayeredCache {
    private l1Cache;
    private l2Cache;
    private l3Cache;
    constructor();
    /**
     * 智能获取缓存
     */
    get(key: string): any;
    /**
     * 智能设置缓存
     */
    set(key: string, data: any, priority?: 'hot' | 'warm' | 'cold'): void;
    /**
     * 获取综合统计
     */
    getStats(): {
        l1: CacheStats;
        l2: CacheStats;
        l3: CacheStats;
    };
    /**
     * 清空所有缓存
     */
    clear(): void;
}
export declare const globalCache: LayeredCache;
export declare const articleCache: SmartCache<any>;
export declare const pinCache: SmartCache<any>;
export declare const trendCache: SmartCache<any>;
export declare const userCache: SmartCache<any>;
export declare const recommendationCache: SmartCache<any>;
export {};
